'''OpenGL extension EXT.discard_framebuffer

This module customises the behaviour of the 
OpenGL.raw.GLES1.EXT.discard_framebuffer to provide a more 
Python-friendly API

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/discard_framebuffer.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES1 import _types, _glgets
from OpenGL.raw.GLES1.EXT.discard_framebuffer import *
from OpenGL.raw.GLES1.EXT.discard_framebuffer import _EXTENSION_NAME

def glInitDiscardFramebufferEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glDiscardFramebufferEXT.attachments size not checked against numAttachments
glDiscardFramebufferEXT=wrapper.wrapper(glDiscardFramebufferEXT).setInputArraySize(
    'attachments', None
)
### END AUTOGENERATED SECTION


'''OpenGL extension OES.get_program_binary

This module customises the behaviour of the 
OpenGL.raw.GLES2.OES.get_program_binary to provide a more 
Python-friendly API

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/OES/get_program_binary.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.OES.get_program_binary import *
from OpenGL.raw.GLES2.OES.get_program_binary import _EXTENSION_NAME

def glInitGetProgramBinaryOES():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glGetProgramBinaryOES.binary size not checked against bufSize
glGetProgramBinaryOES=wrapper.wrapper(glGetProgramBinaryOES).setInputArraySize(
    'binary', None
).setInputArraySize(
    'binaryFormat', 1
).setInputArraySize(
    'length', 1
)
# INPUT glProgramBinaryOES.binary size not checked against length
glProgramBinaryOES=wrapper.wrapper(glProgramBinaryOES).setInputArraySize(
    'binary', None
)
### END AUTOGENERATED SECTION


'''OpenGL extension NV.render_texture_rectangle

This module customises the behaviour of the 
OpenGL.raw.WGL.NV.render_texture_rectangle to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension allows a color buffer with non-power-of-two dimensions to
	be used for both rendering and texturing.  It is built upon the
	ARB_render_texture extension; the only addition in this extension is the
	ability to bind a texture to a texture rectangle target, as provided
	through the NV_texture_rectangle extension.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/render_texture_rectangle.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.WGL import _types, _glgets
from OpenGL.raw.WGL.NV.render_texture_rectangle import *
from OpenGL.raw.WGL.NV.render_texture_rectangle import _EXTENSION_NAME

def glInitRenderTextureRectangleNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLX import _types as _cs
# End users want this...
from OpenGL.raw.GLX._types import *
from OpenGL.raw.GLX import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLX_ARB_create_context_robustness'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLX,'GLX_ARB_create_context_robustness',error_checker=_errors._error_checker)
GLX_CONTEXT_RESET_NOTIFICATION_STRATEGY_ARB=_C('GLX_CONTEXT_RESET_NOTIFICATION_STRATEGY_ARB',0x8256)
GLX_CONTEXT_ROBUST_ACCESS_BIT_ARB=_C('GLX_CONTEXT_ROBUST_ACCESS_BIT_ARB',0x00000004)
GLX_LOSE_CONTEXT_ON_RESET_ARB=_C('GLX_LOSE_CONTEXT_ON_RESET_ARB',0x8252)
GLX_NO_RESET_NOTIFICATION_ARB=_C('GLX_NO_RESET_NOTIFICATION_ARB',0x8261)




'''OpenGL extension EXT.swap_control

This module customises the behaviour of the 
OpenGL.raw.WGL.EXT.swap_control to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension allows an application to specify a minimum
	periodicity of color buffer swaps, measured in video frame periods,
	for a particular drawable. It also allows an application to query
	the swap interval and the implementation-dependent maximum swap
	interval of a drawable.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/swap_control.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.WGL import _types, _glgets
from OpenGL.raw.WGL.EXT.swap_control import *
from OpenGL.raw.WGL.EXT.swap_control import _EXTENSION_NAME

def glInitSwapControlEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ATI_meminfo'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ATI_meminfo',error_checker=_errors._error_checker)
GL_RENDERBUFFER_FREE_MEMORY_ATI=_C('GL_RENDERBUFFER_FREE_MEMORY_ATI',0x87FD)
GL_TEXTURE_FREE_MEMORY_ATI=_C('GL_TEXTURE_FREE_MEMORY_ATI',0x87FC)
GL_VBO_FREE_MEMORY_ATI=_C('GL_VBO_FREE_MEMORY_ATI',0x87FB)




'''OpenGL extension EXT.output_openwf

This module customises the behaviour of the 
OpenGL.raw.EGL.EXT.output_openwf to provide a more 
Python-friendly API

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/output_openwf.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.EGL import _types, _glgets
from OpenGL.raw.EGL.EXT.output_openwf import *
from OpenGL.raw.EGL.EXT.output_openwf import _EXTENSION_NAME

def glInitOutputOpenwfEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_timer_query'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_timer_query',error_checker=_errors._error_checker)
GL_TIMESTAMP=_C('GL_TIMESTAMP',0x8E28)
GL_TIME_ELAPSED=_C('GL_TIME_ELAPSED',0x88BF)
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLint64Array)
def glGetQueryObjecti64v(id,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLuint64Array)
def glGetQueryObjectui64v(id,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum)
def glQueryCounter(id,target):pass
